@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
+# Copyright (c) 2015-2019 Thierry Florac <tflorac AT ulthar.net>
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,21 +12,23 @@
 
 """PyAMS_utils package
 
-This package provides several small modules dedicated to generic features
-for which dedicated packages are not provided. These features can concern
-date and times management, strings and unicode, lists and dictionaries,
-custom decorators to define several kinds of properties, and so on.
+PyAMS generic modules
 """
 
-from pyramid.i18n import TranslationStringFactory
+from fanstatic import Library
 from zope.schema.fieldproperty import FieldProperty
 
 
 __docformat__ = 'restructuredtext'
 
+
+from pyramid.i18n import TranslationStringFactory
 _ = TranslationStringFactory('pyams_utils')
 
 
+library = Library('pyams', '.')
+
+
 def get_field_doc(self):
     """Try to get FieldProperty field docstring from field interface"""
     field = self._FieldProperty__field  # pylint: disable=protected-access
