@@ -24,9 +24,13 @@ __docformat__ = 'restructuredtext'
 class ITALESExtension(Interface):
     """Custom TALES extension
 
-    These extensions will be registered throught adapters for
-    (context, request, view) or (context, request)
+    These extensions will be registered through adapters for
+    (context, request, view) or (context, request).
     """
 
     def render(self, context=None):
-        """Render extension"""
+        """Render extension
+
+        This method can return HTML code which will be inserted directly into an HTML template,
+        but can also return any value which will be assigned to a local template variable.
+        """
